# duckql-django 🐥

backboneQL bindings into [Django](https://www.djangoproject.com/) ORM and permissions system. This package suppose
to provide:

- Database introspection
- Ability to grant permissions to models and their properties
- Custom back-end query validation

---
Made with ☕️ and ❤️ by Jakub Dubec & [BACKBONE s.r.o.](https://www.backbone.sk/en/)
